@@ -4,16 +4,6 @@ import collections
 import os.path
 
 
-def nested_update(d, u):
-    """Update nested dictionary d (in-place) with keys from u."""
-    for k, v in u.items():
-        if isinstance(v, collections.Mapping):
-            d[k] = nested_update(d.get(k, {}), v)
-        else:
-            d[k] = v
-    return d
-
-
 def abs_path(path):
     """Make path absolute."""
     return os.path.join(
@@ -88,9 +78,9 @@ def prepare_spec(spec, data=None):
         data = sanitize_dataframe(data)
         spec['data'] = {'values': data.to_dict(orient='records')}
     elif data is None:
-        # Data is either passed in spec or error
-        if 'data' not in spec:
-            raise ValueError('No data provided')
+        # Assume data is within spec & do nothing
+        # It may be deep in the spec rather than at the top level
+        pass
     else:
         # As a last resort try to pass the data to a DataFrame and use it
         data = pd.DataFrame(data)
